Tutorial — satlas2 0.1.6 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Tutorial

- Making a model
- Fitting in SATLAS2
  - Gaussian fitting
  - Adding prior to parameters
  - Fitting with likelihood data
  - Using Poisson likelihood
  - Using `emcee`
- Extracting dataframes
- Benchmark of SATLAS2 speed
- Using the SATLAS interface
  - Fitting a single hyperfine spectrum
  - Overlapping hyperfine spectra
  - Different background for multiplets